http

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var EmbedFrontend = "false"

EmbedFrontend is a flag to enable or disable embedding the frontend This is useful for testing purposes, where we might not want to embed the frontend During build time, we can set this to false to disable embedding the frontend

var EnableCors = "true"

EnableCors is a flag to enable or disable CORS This is useful for testing purposes, where we might not want to enable CORS During build time, we can set this to false to disable CORS

var Environment = "development"

Environment is a flag to set the environment

Functions

func NewRouter

func NewRouter(wikiInstance *noteroot.NoteRoot) *gin.Engine

Types

This section is empty.

Directories

Path Synopsis

Jump to